@@ -34,8 +34,15 @@ extern "C" {
 #include "data-impl.h"
 
 #ifdef HAVE_GKR
+#if GTK_CHECK_VERSION(3,0,0)
+  #define GCR_API_SUBJECT_TO_CHANGE
+  #include <libsecret/secret.h>
+  #include <gcr/gcr.h>
+  #undef GCR_API_SUBJECT_TO_CHANGE
+#else
   #include <gnome-keyring-1/gnome-keyring.h>
   #include <gnome-keyring-1/gnome-keyring-memory.h>
+#endif /* GTK_CHECK_VERSION(3,0,0) */
 #endif
 
 using namespace pan;
@@ -131,6 +138,54 @@ DataImpl :: save_state ()
 }
 
 #ifdef HAVE_GKR
+#if GTK_CHECK_VERSION(3,0,0)
+gboolean
+DataImpl :: password_encrypt (const PasswordData& pw)
+{
+GError *error_c = NULL;
+
+  return (
+    secret_password_store_sync (
+      SECRET_SCHEMA_COMPAT_NETWORK,
+      SECRET_COLLECTION_DEFAULT,
+      _("Pan Newsreader's server passwords"),
+      pw.pw,
+      NULL, &error_c,
+      "user", pw.user.str,
+      "server", pw.server.c_str(),
+      NULL)
+    );
+
+}
+
+gchar*
+DataImpl :: password_decrypt (PasswordData& pw) const
+{
+  GError *error_c = NULL;
+  gchar* pwd = NULL;
+
+  pwd =
+    secret_password_lookup_sync (
+    SECRET_SCHEMA_COMPAT_NETWORK,
+    NULL,
+    &error_c,
+    "user", pw.user.str,
+    "server", pw.server.c_str(),
+    NULL);
+
+  if (pwd)
+  {
+    pw.pw = gcr_secure_memory_strdup(pwd);
+    secret_password_free(pwd);
+  }
+  else
+  {
+    pw.pw = const_cast<gchar*>("");
+  }
+
+  return pwd;
+}
+#else
 GnomeKeyringResult
 DataImpl :: password_encrypt (const PasswordData& pw)
 {
@@ -176,4 +231,5 @@ DataImpl :: password_decrypt (PasswordData& pw) const
 
   return (pw.pw ? GNOME_KEYRING_RESULT_OK : GNOME_KEYRING_RESULT_DENIED) ;
 }
+#endif /* GTK_CHECK_VERSION(3,0,0) */
 #endif
