@@ -241,6 +241,32 @@ DataImpl :: get_server_auth (const Quark   & server,
     setme_username = s->username;
 #ifndef HAVE_GKR
     setme_password = g_strdup(s->password.c_str());
+#else
+#if GTK_CHECK_VERSION(3,0,0)
+    if (!use_gkr)
+    {
+      setme_password = g_strdup(s->password.c_str());
+    }
+    else if (s->gkr_pw)
+    {
+      setme_password = s->gkr_pw;
+    }
+    else
+    {
+      PasswordData pw;
+      pw.server = s->host;
+      pw.user = s->username;
+
+      if (password_decrypt(pw) == NULL)
+      {
+      Log::add_urgent_va (_("Received no password from libsecret for server %s."), s->host.c_str());
+      }
+      else
+      {
+          setme_password = pw.pw;
+          s->gkr_pw = pw.pw;
+      }
+    }
 #else
     if (!use_gkr)
     {
@@ -275,6 +301,7 @@ DataImpl :: get_server_auth (const Quark   & server,
           break;
       }
     }
+#endif /* GTK_CHECK_VERSION(3,0,0) */
 #endif
   }
 
@@ -512,7 +539,7 @@ DataImpl :: load_server_properties (const DataIO& source)
 #ifndef HAVE_GKR
     s.password = kv["password"];
 #else
-    if (!_prefs.get_flag("use-gnome-keyring", false))
+    if (!_prefs.get_flag("use-password-storage", false))
       s.password = kv["password"];
 #endif
     s.port = to_int (kv["port"], STD_NNTP_PORT);
@@ -570,14 +597,14 @@ DataImpl :: save_server_properties (DataIO& data_io, Prefs& prefs)
     const Server* s (find_server (*it));
     std::string user;
     gchar* pass(NULL);
-    get_server_auth(*it, user, pass, prefs.get_flag("use-gnome-keyring",false));
+    get_server_auth(*it, user, pass, prefs.get_flag("use-password-storage",false));
     *out << indent(depth++) << "<server id=\"" << escaped(it->to_string()) << "\">\n";
     *out << indent(depth) << "<host>" << escaped(s->host) << "</host>\n"
          << indent(depth) << "<port>" << s->port << "</port>\n"
          << indent(depth) << "<username>" << escaped(user) << "</username>\n";
 #ifdef HAVE_GKR
-if (prefs.get_flag("use-gnome-keyring", false))
-    *out << indent(depth) << "<password>" << "HANDLED_BY_GNOME_KEYRING" << "</password>\n";
+if (prefs.get_flag("use-password-storage", false))
+    *out << indent(depth) << "<password>" << "HANDLED_BY_PASSWORD_STORAGE" << "</password>\n";
 else
     *out << indent(depth) << "<password>" << escaped(pass) << "</password>\n";
 #else
