@@ -1061,8 +1061,8 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
 
     // Gnome Keyring Option
     HIG :: workarea_add_section_spacer (t, row, 2);
-    HIG :: workarea_add_section_title (t, &row, _("GNOME Keyring"));
-    w = new_check_button (_("Store passwords in GNOME Keyring"), "use-gnome-keyring", false, prefs);
+    HIG :: workarea_add_section_title (t, &row, _("Password Storage"));
+    w = new_check_button (_("Save passwords in password storage"), "use-password-storage", false, prefs);
     HIG :: workarea_add_wide_control (t, &row, w);
 
   HIG :: workarea_finish (t, &row);
