@@ -43,6 +43,15 @@ extern "C" {
   #include <gnutls/gnutls.h>
 #endif
 
+#ifdef HAVE_GKR
+#if GTK_CHECK_VERSION(3,0,0)
+  #define GCR_API_SUBJECT_TO_CHANGE
+  #include <libsecret/secret.h>
+  #include <gcr/gcr.h>
+  #undef GCR_API_SUBJECT_TO_CHANGE
+#endif /* GTK_CHECK_VERSION(3,0,0) */
+#endif
+
 using namespace pan;
 
 /************
@@ -133,7 +142,7 @@ namespace
     gchar* pass(NULL);
     if (!server.empty()) {
       d->data.get_server_addr (server, addr, port);
-      d->data.get_server_auth (server, user, pass, prefs.get_flag("use-gnome-keyring",false));
+      d->data.get_server_auth (server, user, pass, prefs.get_flag("use-password-storage",false));
       age = d->data.get_server_article_expiration_age (server);
       rank = d->data.get_server_rank (server);
       max_conn = d->data.get_server_limits (server);
@@ -224,7 +233,11 @@ namespace
       const int max_conn (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(d->connection_limit_spin)));
       StringView user (pan_entry_get_text (d->auth_username_entry));
 #ifdef HAVE_GKR
+#if GTK_CHECK_VERSION(3,0,0)
+      gchar* pass = gcr_secure_memory_strdup(gtk_entry_get_text(GTK_ENTRY(d->auth_password_entry)));
+#else
       gchar* pass = gnome_keyring_memory_strdup(gtk_entry_get_text(GTK_ENTRY(d->auth_password_entry)));
+#endif /* GTK_CHECK_VERSION(3,0,0) */
 #else
       gchar* pass = (gchar*)gtk_entry_get_text(GTK_ENTRY(d->auth_password_entry));
 #endif
@@ -271,7 +284,7 @@ namespace
         if (d->server.empty())
           d->server = d->data.add_new_server ();
         d->data.set_server_addr (d->server, addr, port);
-        d->data.set_server_auth (d->server, user, pass, d->prefs.get_flag("use-gnome-keyring",false));
+        d->data.set_server_auth (d->server, user, pass, d->prefs.get_flag("use-password-storage",false));
         d->data.set_server_limits (d->server, max_conn);
         d->data.set_server_article_expiration_age (d->server, age);
         d->data.set_server_rank (d->server, rank);
