@@ -41,7 +41,8 @@ using namespace pan;
 
 Decoder :: Decoder (WorkerPool& pool):
   _worker_pool (pool),
-  _gsourceid (-1)
+  _gsourceid (-1),
+  health(OK)
 {
 }
 
@@ -72,6 +73,7 @@ Decoder :: enqueue (TaskArticle                     * task,
   this->attachment_filename = filename;
 
   mark_read = false;
+
   percent = 0;
   num_scanned_files = 0;
   current_file.clear ();
@@ -305,12 +307,10 @@ Decoder :: progress_update_timer_func (gpointer decoder)
   Task *task = self->task;
   if (!task || self->was_cancelled()) return false;
 
-  self->mut.lock();
   const double percent (self->percent);
   const std::string f (content_to_utf8 (self->current_file));
-  self->mut.unlock();
 
-  task->set_step(int(percent));
+  task->set_step((int)percent);
   task->set_status_va (_("Decoding %s"), f.c_str());
 
   return true; // keep timer func running
