@@ -19,9 +19,10 @@
 
 #include <config.h>
 #include <cctype>
-#include <pan/general/string-view.h>
-#include "numbers.h"
+#include <cstdio> // snprintf
 #include <algorithm>
+#include <glib.h>
+#include "numbers.h"
 
 using namespace pan;
 
@@ -36,11 +37,11 @@ namespace
    typedef Numbers::ranges_t::const_iterator r_cit;
 
    bool
-   maybe_merge_ranges (Numbers::ranges_t & ranges, int low)
+   maybe_merge_ranges (Numbers::ranges_t & ranges, Numbers::ranges_t::size_type low)
    {
       bool merged = false;
 
-      if (0<=low && low<=(int)ranges.size()-2)
+      if (low+2<=ranges.size())
       {
          Numbers::Range & r1 = ranges[low];
          Numbers::Range & r2 = ranges[low+1];
@@ -59,20 +60,20 @@ namespace
 /**
  * @return the number of articles newly-marked as read 
  */
-unsigned long
+uint64_t
 Numbers :: mark_range (const Range& rr)
 {
-   int i;
-   unsigned long retval = 0;
+   ranges_t::size_type i;
+   uint64_t retval = 0;
    bool range_found = false;
-   int low_index (std::lower_bound (_marked.begin(), _marked.end(), rr.low)
+   ranges_t::size_type low_index (std::lower_bound (_marked.begin(), _marked.end(), rr.low)
                   - _marked.begin());
-   int high_index (std::lower_bound (_marked.begin(), _marked.end(), rr.high)
+   ranges_t::size_type high_index (std::lower_bound (_marked.begin(), _marked.end(), rr.high)
                    - _marked.begin());
 
    retval = rr.high + 1 - rr.low;
 
-   for (i=low_index; i<=high_index && i<(int)_marked.size(); ++i)
+   for (i=low_index; i<=high_index && i<_marked.size(); ++i)
    {
       Range& r = _marked[i];
 
@@ -97,7 +98,7 @@ Numbers :: mark_range (const Range& rr)
       }
       else if (r.contains (rr.low)) /* change high */
       {
-         Range * next = i==(int)_marked.size()-1 ? NULL : &_marked[i+1];
+         Range * next = i==_marked.size()-1 ? NULL : &_marked[i+1];
          range_found = true;
          retval -= r.high+1 - rr.low; /* remove intersection from retval */
          r.high = next ? std::min(rr.high, next->low-1) : rr.high;
@@ -107,11 +108,11 @@ Numbers :: mark_range (const Range& rr)
    if (!range_found)
    {
       _marked.insert (_marked.begin()+low_index, rr);
-      --low_index;
+      if (low_index!=0) --low_index;
       ++high_index;
    }
 
-   for (i=low_index; i<=high_index && i<(int)_marked.size(); )
+   for (i=low_index; i<=high_index && i<_marked.size(); )
    {
       if (maybe_merge_ranges (_marked, i))
          --high_index;
@@ -122,17 +123,17 @@ Numbers :: mark_range (const Range& rr)
    return retval;
 }
 
-unsigned long
+uint64_t
 Numbers :: unmark_range (const Range& ur)
 {
-   unsigned long retval = 0;
-   int i;
-   int low_index (std::lower_bound (_marked.begin(), _marked.end(), ur.low)
+   uint64_t retval = 0;
+   ranges_t::size_type i;
+   ranges_t::size_type low_index (std::lower_bound (_marked.begin(), _marked.end(), ur.low)
                   - _marked.begin());
-   int high_index (std::lower_bound (_marked.begin(), _marked.end(), ur.high)
+   ranges_t::size_type high_index (std::lower_bound (_marked.begin(), _marked.end(), ur.high)
                    - _marked.begin ());
 
-   for (i=low_index; i<=high_index && i<(int)_marked.size(); )
+   for (i=low_index; i<=high_index && i<_marked.size(); )
    {
       Range& r (_marked[i]);
       if (ur.contains (r)) // remove
@@ -172,17 +173,17 @@ Numbers :: unmark_range (const Range& ur)
 ******  MARK (PUBLIC)
 *****/
 
-unsigned long
-Numbers :: mark_range (unsigned long low, unsigned long high, bool add)
+uint64_t
+Numbers :: mark_range (uint64_t low, uint64_t high, bool add)
 {
    const Range r (low, high);
    return add ? mark_range(r) : unmark_range(r);
 }
 
 bool
-Numbers :: mark_one (unsigned long number, bool add)
+Numbers :: mark_one (uint64_t number, bool add)
 {
-   const unsigned long changed_qty (mark_range (number, number, add));
+   const uint64_t changed_qty (mark_range (number, number, add));
 
    if (add)
       return changed_qty==0;
@@ -201,8 +202,8 @@ Numbers :: mark_str (const StringView& str, bool add)
       phigh.pop_token (plow, '-');
       plow.trim ();
       phigh.trim ();
-      const unsigned long low (plow.empty() ? 0 : strtoul (plow.str, NULL, 10));
-      const unsigned long high (phigh.empty() ? low : strtoul (phigh.str, NULL, 10));
+      const uint64_t low (plow.empty() ? 0 : g_ascii_strtoull (plow.str, NULL, 10));
+      const uint64_t high (phigh.empty() ? low : g_ascii_strtoull (phigh.str, NULL, 10));
       mark_range (low, high, add);
    }
 }
@@ -218,7 +219,7 @@ Numbers :: clear ()
 *****/
 
 void
-Numbers :: clip (unsigned long low, unsigned long high)
+Numbers :: clip (uint64_t low, uint64_t high)
 {
    r_it it = std::lower_bound (_marked.begin(), _marked.end(), low);
    _marked.erase (_marked.begin(), it);
@@ -237,7 +238,7 @@ Numbers :: clip (unsigned long low, unsigned long high)
 *****/
 
 bool
-Numbers :: is_marked (unsigned long number) const
+Numbers :: is_marked (uint64_t number) const
 {
    r_cit it = std::lower_bound (_marked.begin(), _marked.end(), number);
 
@@ -256,23 +257,22 @@ Numbers :: to_string () const
 void
 Numbers :: to_string (std::string & str) const
 {
+   std::string temp;
+   int bytes;
    char buf[64];
 
+   temp.reserve(24 * _marked.size() );
    for (r_cit it=_marked.begin(), end=_marked.end(); it!=end; ++it)
    {
       Range r (*it);
 
-      snprintf (buf, sizeof(buf), "%lu", r.low);
-      str += buf;
-
-      if (r.low != r.high) {
-         snprintf (buf, sizeof(buf), "-%lu", r.high);
-         str += buf;
-      }
-
-      str += ',';
+      if (r.low == r.high)
+        bytes = g_snprintf (buf, sizeof(buf), "%" G_GUINT64_FORMAT",", r.low);
+      else
+         bytes = g_snprintf (buf, sizeof(buf), "%" G_GUINT64_FORMAT"-%" G_GUINT64_FORMAT",", r.low, r.high);
+      temp.append(buf, bytes);
    }
 
-   if (!str.empty())
-      str.erase (--str.end()); // remove final comma
+   if (!temp.empty())
+      str.append(temp.begin(), --temp.end()); // remove final comma
 }
